powered by
Initializes a subspace stratified design before the start of the study.
strat_start(p0_sub, p1_sub, distr_sub, alpha = 0.05, beta = 0.2)
A vector, where the $i$-th entry corresponds to the response rate under the null for the $i$-th subtype.
A vector, where the $i$-th entry corresponds to the response rate under the alternative for the $i$-th subtype.
A vector, where the $i$-th entry corresponds to the prevalence of the $i$-th subtype in the population.
Specified type I error of the trial.
Specified type II error of the trial.
A list returning the arguments of the function and the preliminary design for starting the stratified trial.
# NOT RUN { p0_sub <- c(0.1, 0.3, 0.5) p1_sub <- c(0.3, 0.5, 0.7) distr_sub <- c(1/3, 1/3, 1/3) strat_start(p0_sub, p1_sub, distr_sub) # }
Run the code above in your browser using DataLab